<script setup>
import { getCurrentInstance, ref, computed, reactive, onMounted } from 'vue';
import { get, post, postBlob } from '@/utils/request.js'
import * as Icons from "@ant-design/icons-vue";
import EditView from './edit.vue'
import { message, Modal } from 'ant-design-vue';
import { formatMessage } from '@/utils/localeUtils.js';
import { logout } from '@/config.js';
const context = getCurrentInstance()?.appContext.config.globalProperties;
const components = {
  ...Icons,
};

const searchInput = ref("")
const editChild = ref(null)

const state = reactive({
  selectedRowKeys: [],
  loading: false,
});

let tableData = ref([]);
getPage();

const typeMap = {
  0: {
    color: 'success',
    text: '菜单',
  },
  1: {
    color: 'default',
    text: '按钮',
  },
};

const hasSelected = computed(() => state.selectedRowKeys.length > 0);
const start = () => {
  state.loading = true;
  // ajax request after empty completing
  setTimeout(() => {
    state.loading = false;
    state.selectedRowKeys = [];
  }, 1000);
};
const onSelectChange = selectedRowKeys => {
  // console.log('selectedRowKeys changed: ', selectedRowKeys);
  state.selectedRowKeys = selectedRowKeys;
};

function getPage() {
  state.loading = true;
  post('/api/menu/tree', {}).then((result) => {
    if (result.data.code == 200) {
      let data = result.data.data;
      tableData.value = data;
      // console.log(data);
      editChild.value.treeData = [{
        id: 0,
        name: '根目录',
        children: data
      }];

      state.loading = false;
    } else if (result.code === 401) {
      message.error(result.msg);
      logout()
    } else {
      message.error(result.msg);
    }
  })
}

const handleEdit = (item) => {
  editChild.value.open = true;
  editChild.value.formData = item == null ? editChild.value.initFormData : item;
  editChild.value.isSave = item == null;
}

const handleDel = (rows) => {
  Modal.confirm({
    title: formatMessage('page.delete', '删除'),
    content: formatMessage('page.delete.confirm', '确定删除该项吗？'),
    maskClosable: true,
    onOk: async () => {
      const hide = message.loading(formatMessage('common.loading', '请求中'));
      try {
        post('/api/menu/remove/' + rows.map((row) => row.id).join(','), {}).then(resp => {
          let result = resp.data;
          if (result.code === 200) {
            message.success(result.msg);
          } else {
            message.error(result.msg);
          }
          getPage()
          hide()
        })
      } catch (error) {
        message.error(formatMessage('common.fail', '请求失败'));
      }
    },
  });
}

const handleExport = async (intl) => {
  postBlob('/api/menu/export', {}).then(result => {
    const blob = new Blob([result.data], { type: 'application/vnd.ms-excel' });
    window.location.href = window.URL.createObjectURL(blob);
    return true;
  })
};

const onSearch = () => {
  // console.log('search');
  getPage()
}

function handleTableReload(value) {
  getPage()
}

</script>

<script>
export default {
  name: '菜单管理'
}
</script>

<template>
  <div>
    <EditView ref="editChild" @tableReload="handleTableReload" />
    <div class="table-header">
      <a-input-search v-model:value="searchInput" placeholder="请输入" style="width: 200px;" @search="onSearch" />
      <div class="table-header-right">
        <a-button @click="handleEdit(null)" type="primary">{{ formatMessage('page.add', '添加') }}</a-button>
        <a-button @click="handleExport">{{ formatMessage('page.export', '导出') }}</a-button>
      </div>
    </div>
    <a-table :row-selection="{ selectedRowKeys: state.selectedRowKeys, onChange: onSelectChange }"
      :data-source="tableData" :defaultExpandAllRows="false" key="menu" rowKey="id" :loading="state.loading" :scroll="{ y: 780 }">
      <a-table-column :title="formatMessage('db.sys_menu.name', '菜单名称')" key="name" data-index="name" />
      <a-table-column :title="formatMessage('db.sys_menu.route', '路由地址')" key="route" data-index="route" />
      <a-table-column :title="formatMessage('db.sys_menu.type', '类型')" key="type" data-index="type$">
        <template #default="{ record }">
          <span>
            <a-tag :color="typeMap[record.type].color">{{ record.type$ }}</a-tag>
          </span>
        </template>
      </a-table-column>
      <a-table-column :title="formatMessage('db.sys_menu.authority', '权限标识')" key="authority" data-index="authority" />
      <a-table-column :title="formatMessage('db.sys_menu.icon', '菜单图标')" key="icon" data-index="icon">
        <template #default="{ record }">
          <component :is="components[ref(record.icon).value]" />
        </template>
      </a-table-column>
      <a-table-column :title="formatMessage('db.sys_menu.language_id', '国际化ID')" key="languageId"
        data-index="languageId" />
      <a-table-column :title="formatMessage('db.sys_menu.sort', '排序')" key="sort" data-index="sort" />
      <a-table-column :title="formatMessage('db.sys_menu.status', '状态')" key="status$" data-index="status$" />
      <a-table-column :title="formatMessage('db.sys_menu.update_time', '修改时间')" key="updateTime$"
        data-index="updateTime$" />
      <a-table-column :title="formatMessage('common.operation', '操作')" key="oper" data-index="oper">
        <template #default="{ record }">
          <div style="display: flex;justify-content: space-evenly;">
            <a-button type="link" primary @click="handleEdit(record)">{{ formatMessage('page.edit', '编辑') }}</a-button>
            <a-button type="link" danger @click="handleDel([record])">{{ formatMessage('page.delete', '删除')
              }}</a-button>
          </div>
        </template>
      </a-table-column>
    </a-table>
  </div>
</template>

<style></style>